@@ -12,37 +12,6 @@ import pomsets.resource as ResourceModule
 import pomsets.parameter as ParameterModule
 
 
-def sortParameters(parameters, orderings):
-    # TODO:
-    # this is not the most efficient implementation
-    # i.e. it creates too many intermediate data structures
-    # will have to optimize
-    
-    # map according to id
-    idMap = dict([(x.id(), x) for x in parameters])
-    
-    # first find all the parameters w/o precedings
-    successors = {}
-    relations = {}
-    for row in orderings.rows():
-        predecessor = row.getColumn('source')
-        successor = row.getColumn('target')
-        relations[predecessor] = \
-            relations.get(predecessor, []) + [successor]
-        successors[successor] = []
-        pass
-
-    toProcess = list(set(idMap.keys()).difference(set(successors.keys())))
-    sorted = []
-    while len(toProcess):
-        current = toProcess.pop(0)
-        if current in sorted:
-            continue
-        toProcess.extend(relations.get(current, []))
-        sorted.append(current)
-        pass
-    
-    return [idMap[x] for x in sorted]
 
 
 def buildCommandFunction_default(task):
@@ -71,16 +40,14 @@ def buildCommandFunction_commandlineArgsOnly(task):
     
     parameterBindings = task.parameterBindings()
     
-    commandlineParameterFilter = FilterModule.ObjectKeyMatchesFilter(
-        filter = FilterModule.IdentityFilter(True),
-        keyFunction = lambda x: x.getAttribute(ParameterModule.PORT_ATTRIBUTE_COMMANDLINE)
-    )
-    
+    commandlineParameterFilter = \
+        task.definition().getFilterForCommandlineArguments()
+
     commandLineParameters = [
         x for x in
         task.definition().getParametersByFilter(commandlineParameterFilter)]
 
-    commandLineParameters = sortParameters(
+    commandLineParameters = ParameterModule.sortParameters(
         commandLineParameters, 
         task.definition().parameterOrderingTable())
     
@@ -199,50 +166,38 @@ class Executable(ResourceModule.Struct):
 
 
 
-class PrintTaskCommand(ExecuteEnvironmentModule.Environment):
+class PrintTaskCommand(ExecuteEnvironmentModule.Environment, ResourceModule.Struct):
     
     DEFAULT_COMMANDBUILDER_TYPE = 'print task'
     
+    ATTRIBUTES = [
+        'outputStream',
+        'prefix',
+        'postfix'
+        ]
+
     def __init__(self):
+        ResourceModule.Struct.__init__(self)
         return
     
-    def outputStream(self, value=None):
-        if value is not None:
-            self._outputStream = value
-        if not hasattr(self, '_outputStream'):
-            self._outputStream = None
-        return self._outputStream
-
-    def prefix(self, value=None):
-        if value is not None:
-            self._prefix = value
-        if not hasattr(self, '_prefix'):
-            self._prefix = None
-        return self._prefix
-
-    def postfix(self, value=None):
-        if value is not None:
-            self._postfix = value
-        if not hasattr(self, '_postfix'):
-            self._postfix = None
-        return self._postfix
-
     def execute(self, task, *args, **kargs):
         
         commandBuilder = self.getCommandBuilder(task)
         
         command = commandBuilder.buildCommand(task)
 
-        if self.prefix():
-            self.outputStream().write(self.prefix())
-
-        self.outputStream().write(task.definition().name() + '\n')
         if self.outputStream():
+            if self.prefix():
+                self.outputStream().write(self.prefix())
+
+            self.outputStream().write(task.definition().name() + '\n')
             self.outputStream().write(' '.join(command))
-        if self.postfix():
-            self.outputStream().write(self.postfix())
+
+            if self.postfix():
+                self.outputStream().write(self.postfix())
         
         return 0
+
     
     # END class PrintTaskCommand
     pass
