@@ -578,7 +578,14 @@ class CompositeDefinition(GraphModule.Graph, Definition,
         # remove any blackboard parameters
         for connections, additionalParameterIds in self.parameterConnectionPathTable().retrieve(filter=filter, columns=['path', 'additional parameters']):
 
-            map(self.removeParameterConnection, list(connections))
+            if connections is None:
+                # we reach here if the connection path
+                # is actually exposing the node parameter
+                # to the parent pomset
+                pass
+            else:
+                map(self.removeParameterConnection, list(connections))
+
             parameters = [self.getParameter(x) 
                           for x in additionalParameterIds]
             map(self.removeParameter, parameters)
@@ -695,7 +702,34 @@ class CompositeDefinition(GraphModule.Graph, Definition,
 
         return edge
 
-    
+
+    def exposesNodeParameter(self, node, nodeParameterId):
+
+        # we check the parameter connection path
+        # for one of two possibilities
+        # self.x -> node.nodeParameterId
+        # or
+        # node.nodeParameterId -> self.x
+        filter = FilterModule.constructOrFilter()
+        filter.addFilter(
+            self.constructParameterConnectionFilter(
+                sourceNode=self,
+                targetNode=node,
+                targetParameterId=nodeParameterId)
+            )
+        filter.addFilter(
+            self.constructParameterConnectionFilter(
+                sourceNode=node,
+                sourceParameterId=nodeParameterId,
+                targetNode=self
+                )
+            )
+        paths = RelationalModule.Table.reduceRetrieve(
+            self.parameterConnectionPathTable(),
+            filter, ['path'], [])
+        return len(paths) is not 0
+
+
     def exposeNodeParameter(self, 
                             parameterId,
                             node, nodeParameterId,
@@ -721,10 +755,12 @@ class CompositeDefinition(GraphModule.Graph, Definition,
                 portDirection=portDirection)
             parameter.name(parameterId)
             self.parameterIsActive(True)
+
+            parameterAttributes = copy.copy(nodeParameter.attributes())
+            parameterAttributes['commandline'] = False
             ParameterModule.setAttributes(
                 parameter,
-                { 'commandline':False,
-                  ParameterModule.PORT_ATTRIBUTE_ISSIDEEFFECT:parameter.getAttribute(ParameterModule.PORT_ATTRIBUTE_ISSIDEEFFECT)} 
+                parameterAttributes
                 )
             self.addParameter(parameter)
 
@@ -821,33 +857,37 @@ class CompositeDefinition(GraphModule.Graph, Definition,
 
 
     def constructParameterConnectionFilter(self, 
-                                           sourceNode, sourceParameterId,
-                                           targetNode, targetParameterId):
+                                           sourceNode=None, sourceParameterId=None,
+                                           targetNode=None, targetParameterId=None):
         filter = FilterModule.constructAndFilter()
-        filter.addFilter(
-            RelationalModule.ColumnValueFilter(
-                'source node',
-                FilterModule.IdentityFilter(sourceNode)
+        if sourceNode is not None:
+            filter.addFilter(
+                RelationalModule.ColumnValueFilter(
+                    'source node',
+                    FilterModule.IdentityFilter(sourceNode)
+                    )
                 )
-            )
-        filter.addFilter(
-            RelationalModule.ColumnValueFilter(
-                'source parameter',
-                FilterModule.EquivalenceFilter(sourceParameterId)
+        if sourceParameterId is not None:
+            filter.addFilter(
+                RelationalModule.ColumnValueFilter(
+                    'source parameter',
+                    FilterModule.EquivalenceFilter(sourceParameterId)
+                    )
                 )
-            )
-        filter.addFilter(
-            RelationalModule.ColumnValueFilter(
-                'target node',
-                FilterModule.IdentityFilter(targetNode)
+        if targetNode is not None:
+            filter.addFilter(
+                RelationalModule.ColumnValueFilter(
+                    'target node',
+                    FilterModule.IdentityFilter(targetNode)
+                    )
                 )
-            )
-        filter.addFilter(
-            RelationalModule.ColumnValueFilter(
-                'target parameter',
-                FilterModule.EquivalenceFilter(targetParameterId)
+        if targetParameterId is not None:
+            filter.addFilter(
+                RelationalModule.ColumnValueFilter(
+                    'target parameter',
+                    FilterModule.EquivalenceFilter(targetParameterId)
+                    )
                 )
-            )
         return filter
 
 
