@@ -166,7 +166,10 @@ class CompositeTask(Task):
         'tasksTable',
         'allChildTasksHaveCompleted',
         'hasGeneratedTasks',
-        'isParameterSweepTasksHolder'
+        'isParameterSweepTasksHolder',
+        'executionIsPaused',
+        'shouldLimitChildrenConcurrency',
+        'childrenConcurrencyLimit'
     ]
     
     def __init__(self):
@@ -175,6 +178,13 @@ class CompositeTask(Task):
         self.allChildTasksHaveCompleted(False)
         self.initializeTasksTable()
         self.isParameterSweepTasksHolder(False)
+
+        # default to not limiting children concurrency
+        # but once the flag is switched
+        # default to only one
+        self.shouldLimitChildrenConcurrency(False)
+        self.childrenConcurrencyLimit(1)
+
         return
 
     def initializeTasksTable(self):
@@ -347,8 +357,6 @@ class CompositeTask(Task):
             []
         )
         
-        
-
         # if every one of those predecessors
         # can be found in tokens, and vice versa
         readyToExecute = len(set(completedPredecessors).symmetric_difference(allPredecessors)) is 0
@@ -540,7 +548,7 @@ class CompositeTask(Task):
             return True
         return False
     
-        
+
     def initializeForChildDefinition(self, definition):
         command = CommandModule.CompositeCommand()
 
@@ -593,20 +601,17 @@ class CompositeTask(Task):
         self.automaton().executeCommand(command)
 
         # TODO: add this as a critical section
-        #self.completedChildTask = task
+
+        # need to check if all have completed
+        # if so, then mark as completed
+        # otherwise generate more tasks
         if self.taskGenerator().canGenerateMoreTasks(self, completedChildTask=task):
 
             self.taskGenerator().generateReadyTasks(self, completedChildTask=task)
             self.startNextTasks()
         elif self.taskGenerator().allGeneratedTasksHaveExecuted(self):
-            # a maximal node just completed
-            # need to check if all have completed
-            # if so, then mark as completed
             self.postProcessForAllChildTasksHaveCompleted()
             pass
-            
-            pass
-        #del self.completedChildTask
         
         return
 
@@ -811,6 +816,8 @@ class AtomicTask(Task):
         for parameter in self.definition().getParametersByFilter(filter):
             values = self.getParameterBinding(parameter.id())
             for value in values:
+                logging.debug("staging parameter %s file %s" % (parameter.id(),
+                                                                value))
                 shell.stageFile(file=value, task=self, parameter=parameter)
             pass
             
@@ -1117,6 +1124,9 @@ class NestTaskGenerator(TaskGenerator):
     
     def generateReadyTasks(self, parentTask, completedChildTask=None):
 
+        if parentTask.executionIsPaused():
+            return
+
         definitionsForNextTasks = []
         if not hasattr(parentTask, 'hasGeneratedMinimalTasks') or \
            not parentTask.hasGeneratedMinimalTasks:
@@ -1129,13 +1139,28 @@ class NestTaskGenerator(TaskGenerator):
             
         if hasattr(parentTask, 'definitionsForNextTasks'):
             definitionsForNextTasks.extend(parentTask.definitionsForNextTasks)
-        
-        for definitionForNextTask in definitionsForNextTasks:
 
-            if not parentTask.hasInitializedChildTask(definitionForNextTask):
-                parentTask.initializeForChildDefinition(definitionForNextTask)
+        if len(definitionsForNextTasks) is 0:
+            # if there are no more ready tasks
+            # and all generated tasks have executed
+            # (this includes the case where the nest is empty
+            #  i.e. no tasks were generated)
+            # then just call the post process
+            if self.allGeneratedTasksHaveExecuted(parentTask):
+                parentTask.postProcessForAllChildTasksHaveCompleted()
                 pass
+            else:
+                raise NotImplementedError('not implemented for when there are no more tasks ready to execute, but when the nest is not empty')
             pass
+        else:
+            for definitionForNextTask in definitionsForNextTasks:
+                # the task may have already have been initialized
+                # if it is expecting multiple tokens
+                # and this is not the first one
+                if not parentTask.hasInitializedChildTask(definitionForNextTask):
+                    parentTask.initializeForChildDefinition(definitionForNextTask)
+                    pass
+                pass
         
         return
 
@@ -1260,6 +1285,9 @@ class LoopTaskGenerator(TaskGenerator):
     
     def generateReadyTasks(self, parentTask, completedChildTask=None):
         
+        if parentTask.executionIsPaused():
+            return
+
         # the initial state does not satisfy the continue condition
         if not self.canGenerateMoreTasks(parentTask):
             return
@@ -1366,6 +1394,9 @@ class BranchTaskGenerator(TaskGenerator):
 
     def generateReadyTasks(self, parentTask, completedChildTask=None):
         
+        if parentTask.executionIsPaused():
+            return
+
         if not self.canGenerateMoreTasks(
             parentTask, completedChildTask=completedChildTask):
             return
@@ -1482,6 +1513,9 @@ class ParameterSweepTaskGenerator(TaskGenerator):
     
     def generateReadyTasks(self, parentTask, completedChildTask=None):
 
+        if parentTask.executionIsPaused():
+            return
+
         definitionsForNextTasks = []
         
         if not parentTask.hasGeneratedTasks():
@@ -1491,8 +1525,6 @@ class ParameterSweepTaskGenerator(TaskGenerator):
             # that are not Parameter Sweep Tasks
             # but use the same definition
             # we will need to bind the correct values to the parameters
-            # CODE HERE
-            # for definitionForNextTask in definitionsForNextTasks:
 
             # TODO: handle chunking
             # first, we need to determine how many tasks to create
@@ -1510,7 +1542,17 @@ class ParameterSweepTaskGenerator(TaskGenerator):
                 processedGroups.add(group)
                 numTasksToCreate *= numParameters
                 pass
-            
+
+            # This is a bit complicated
+            # so we need to keep track of which index we are in the each ps group
+            # so that we can retrieve the value from the same index in each ps group
+            # but we also need to keep track of where we are in the total tasks
+            # so that we can increment indices in the ps group accordingly
+            # so that when one group rolls over, another gets incremented
+            parameterSweepGroupIndices = [0 for x in processedGroups]
+            indexToGroupMap = dict(enumerate(processedGroups))
+            groupToIndexMap = dict([(y, x) for x, y in enumerate(processedGroups)])
+
             for index in range(numTasksToCreate):
                 parentTask.initializeForChildDefinition(definitionForTask)
                 row = self.taskTable().addRow()
@@ -1519,9 +1561,22 @@ class ParameterSweepTaskGenerator(TaskGenerator):
                 row.setColumn('task', None)
                 parameterBindings = copy.copy(parentTask.parameterBindings())
                 for parameterSweepId, modulus in parameterSweepIdMap.iteritems():
+                    group = definitionForTask.getGroupForParameterSweep(parameterSweepId)
                     parameterBindings[parameterSweepId] = \
-                        [parameterBindings[parameterSweepId][index%modulus]]
+                        [parameterBindings[parameterSweepId][parameterSweepGroupIndices[groupToIndexMap[group]]]]
+                    pass
                 row.setColumn('parameter bindings', parameterBindings)
+
+                psGroupIndex = len(parameterSweepGroupIndices) - 1
+                while True:
+                    parameterSweepGroupIndices[psGroupIndex] = (parameterSweepGroupIndices[psGroupIndex] + 1) % parameterSweepIdMap[indexToGroupMap[psGroupIndex][0]]
+                    if not parameterSweepGroupIndices[psGroupIndex] == 0:
+                        break
+                    psGroupIndex = psGroupIndex - 1
+                    if psGroupIndex < 0:
+                        break
+                    pass
+
                 pass
             
             parentTask.hasGeneratedTasks(True)
