@@ -13,9 +13,10 @@ import pypatterns.command as CommandPatternModule
 import cloudpool as CloudModule
 import cloudpool.shell as ShellModule
 
-import pomsets.automaton as AutomatonModule
 import pypatterns.filter as FilterModule
 
+import pomsets.automaton as AutomatonModule
+import pomsets.builder as BuilderModule
 import pomsets.command as TaskCommandModule
 import pomsets.definition as DefinitionModule
 import pomsets.error as ErrorModule
@@ -31,8 +32,6 @@ def createEchoDefinition():
     command = ['/bin/echo']
     executable = TaskCommandModule.Executable()
     executable.stageable(False)
-    # executable.command(command)
-    # executable.path(command[0])
     executable.path(command)
     executable.staticArgs([])
     
@@ -64,8 +63,13 @@ class BaseTestClass(object):
             CloudModule.Pool(self.getNumWorkersToInstantiate()))
         automaton.commandManager(CommandPatternModule.CommandManager())
         self.automaton = automaton
+
+        builder = BuilderModule.Builder()
+        self.builder = builder
+
         return
 
+
     def tearDown(self):
         return
 
@@ -150,6 +154,24 @@ class BaseTestClass(object):
 
         return
 
+    def createTask(self, reference):
+        
+        definitionToReference = reference.definitionToReference()
+        if definitionToReference.isAtomic():
+            task = TaskModule.AtomicTask()
+            task.definition(reference)
+            return task
+
+        task = TaskModule.CompositeTask()
+        task.definition(reference)
+        taskGenerator = TaskModule.NestTaskGenerator()
+        task.taskGenerator(taskGenerator)
+        return task
+
+
+    def bindTaskParameterValues(self, task):
+        return
+
     def testExecute1(self):
 
         self.assertPreExecute()
@@ -160,6 +182,8 @@ class BaseTestClass(object):
         reference.definitionToReference(definition)
 
         task = self.createTask(reference)
+        self.bindTaskParameterValues(task)
+
         request = self.executeTask(task)
 
         self.request = request
@@ -174,19 +198,30 @@ class BaseTestClass(object):
         self.assertPreExecute()
 
         definition = self.createDefinition()
+        reference = DefinitionModule.ReferenceDefinition()
+        reference.definitionToReference(definition)
 
-        definition = GeneratePomsetsModule.pickleAndReloadDefinition(
+        reference = GeneratePomsetsModule.pickleAndReloadDefinition(
             '.'.join([self.getPicklePath(), 'pomset']),
-            definition
+            reference
         )
 
-        task = self.createTask(definition)
+        task = self.createTask(reference)
+        self.bindTaskParameterValues(task)
+
         request = self.executeTask(task)
         self.request = request
 
         self.assertPostExecute()
         return 
 
+
+    def getPicklePath(self):
+        return os.path.sep + os.path.join(
+            'tmp', '.'.join([self.__class__.__module__,
+                             self.__class__.__module__,
+                             'pickle.pomset']))
+
     
     # END class BaseTestClass
     pass
@@ -200,17 +235,10 @@ class TestCase1(BaseTestClass, unittest.TestCase):
     def createDefinition(self):
         return DEFINITION_ECHO
 
-    def createTask(self, definition):
-        task = TaskModule.AtomicTask()
-
-        task.definition(definition)
-
+    def bindTaskParameterValues(self, task):
         task.setParameterBinding('item to echo', ['foo'])
-        return task
-
-
-    def getPicklePath(self):
-        return os.path.sep + os.path.join('tmp', 'TestExecute.TestCase1.testExecute2')
+        return
+    
 
     # END TestCase1
     pass
@@ -225,18 +253,13 @@ class TestCase2(BaseTestClass, unittest.TestCase):
         definition = DEFINITION_ECHO
         return definition
 
-    def createTask(self, definition):
-
-        task = TaskModule.AtomicTask()
-        task.definition(definition)
+    def bindTaskParameterValues(self, task):
         task.setParameterBinding('item to echo', ['"echoed testExecuteAtomicFunction2"'])
-        return task
+        return
 
-    def getPicklePath(self):
-        return os.path.sep + os.path.join('tmp', 'TestExecute.TestCase2.testExecute2')
 
     # END class TestCase2
-    
+    pass
 
 
 class TestCase4(BaseTestClass, unittest.TestCase):
@@ -263,19 +286,9 @@ class TestCase4(BaseTestClass, unittest.TestCase):
         )
         return compositeDefinition
 
-    def createTask(self, definition):
-
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        compositeTask.setParameterBinding('item to echo', ['foo'])
-
-        return compositeTask
-
-
-    def getPicklePath(self):
-        return os.path.sep + os.path.join('tmp', 'TestExecute.TestCase4.testExecute2')
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding('item to echo', ['foo'])
+        return
 
 
     # END class TestCase4
@@ -310,20 +323,12 @@ class TestCase8(BaseTestClass, unittest.TestCase):
 
         return compositeDefinition
 
-    def createTask(self, definition):
 
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        compositeTask.setParameterBinding('item to echo', ['foo'])
-        
-        return compositeTask
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding('item to echo', ['foo'])
+        return
 
 
-    def getPicklePath(self):
-        return os.path.sep + os.path.join('tmp', 'TestExecute.TestCase8.testExecute2')
-
     # END class TestCase8
     pass
 
@@ -362,21 +367,11 @@ class TestCase9(BaseTestClass, unittest.TestCase):
             pass
         return compositeDefinition
 
-    def createTask(self, definition):
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        
-        compositeTask.setParameterBinding('item to echo', ['foo'])
-        
-        return compositeTask
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding('item to echo', ['foo'])
+        return
 
 
-    def getPicklePath(self):
-        return os.path.sep + os.path.join('tmp', 'TestExecute.TestCase9.testExecute2')
-
-    
     # END class TestCase9
     pass
 
@@ -402,14 +397,9 @@ class TestCase10(BaseTestClass, unittest.TestCase):
         return compositeDefinition
 
 
-    def createTask(self, definition):
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        compositeTask.setParameterBinding('item to echo', ['foo'])
-        
-        return compositeTask
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding('item to echo', ['foo'])
+        return
 
 
     def assertPostExecute(self):
@@ -417,14 +407,130 @@ class TestCase10(BaseTestClass, unittest.TestCase):
         assert request.exception
         return
 
-    def getPicklePath(self):
-        return os.path.sep + os.path.join('tmp', 'TestExecute.TestCase10.testExecute2')
+    # END class TestCase10
+    pass
 
-    # END class TestCase
+
+class TestCase11(TestCase1):
+    """
+    execute of atomic function
+    """
+
+    def getNumWorkersToInstantiate(self):
+        return 0
+
+    
+    def executeTask(self, task, 
+                    executeEnvironmentMap=None):
+
+        automaton = self.automaton
+        successCallback = automaton.getPostExecuteCallbackFor(task)
+        errorCallback = automaton.getErrorCallbackFor(task)
+        executeTaskFunction = automaton.getExecuteTaskFunction(task)
+        
+        requestContext = self.getRequestContext(
+            task=task, executeEnvironmentMap=executeEnvironmentMap
+        )
+        request = threadpool.WorkRequest(
+            executeTaskFunction,
+            args = [],
+            kwds = requestContext,
+            callback = successCallback,
+            exc_callback = errorCallback
+        )
+
+        try:
+            automaton.enqueueRequest(request)
+            assert False
+        except ErrorModule.ExecutionError, e:
+            self.assertEquals('need to start thread before execution',
+                              str(e))
+
+        return request
+
+
+
+    # END TestCase11
+    pass
+
+
+class TestCase12(BaseTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        atomicDefinition = DEFINITION_ECHO
+        nestDefinition = DefinitionModule.getNewNestDefinition()
+        parameter = ParameterModule.DataParameter(
+            id='item to echo', 
+            portDirection=ParameterModule.PORT_DIRECTION_INPUT)
+        nestDefinition.addParameter(parameter)
+        
+        node = nestDefinition.createNode(id='node')
+        node.definitionToReference(atomicDefinition)
+        node.name('echo')
+
+        nestDefinition._connectParameters(
+            nestDefinition, 'item to echo',
+            node, 'item to echo'
+        )
+
+        compositeDefinition = DefinitionModule.getNewNestDefinition()
+        node = compositeDefinition.createNode(id='nest')
+        node.definitionToReference(nestDefinition)
+
+        node.setParameterBinding('item to echo', ['foo'])
+
+        return compositeDefinition
+
+
+    # END class TestCase12
+    pass
+
+
+class TestCase13(BaseTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        atomicDefinition = DEFINITION_ECHO
+        nestDefinition = DefinitionModule.getNewNestDefinition()
+        parameter = ParameterModule.DataParameter(
+            id='item to echo', 
+            portDirection=ParameterModule.PORT_DIRECTION_INPUT)
+        nestDefinition.addParameter(parameter)
+        
+        node = nestDefinition.createNode(id='node')
+        node.definitionToReference(atomicDefinition)
+        node.name('echo')
+
+        nestDefinition._connectParameters(
+            nestDefinition, 'item to echo',
+            node, 'item to echo'
+        )
+
+        compositeDefinition = DefinitionModule.getNewNestDefinition()
+        parameter = ParameterModule.DataParameter(
+            id='item to echo', 
+            portDirection=ParameterModule.PORT_DIRECTION_INPUT)
+        compositeDefinition.addParameter(parameter)
+
+        node = compositeDefinition.createNode(id='nest')
+        node.definitionToReference(nestDefinition)
+
+        compositeDefinition._connectParameters(
+            compositeDefinition, 'item to echo',
+            node, 'item to echo'
+        )
+
+        return compositeDefinition
+
+
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding('item to echo', ['foo'])
+        return
+
+
+    # END class TestCase13
     pass
     
 
-
 class TestParameterSweep1(BaseTestClass, unittest.TestCase):
     
 
@@ -451,21 +557,12 @@ class TestParameterSweep1(BaseTestClass, unittest.TestCase):
 
         return compositeDefinition
 
-    def createTask(self, definition):
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        compositeTask.setParameterBinding(
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding(
             'item to echo', 
-            ['"echoed testExecuteParameterSweep1 : 1"',
-             '"echoed testExecuteParameterSweep1 : 2"'])
-        return compositeTask
-    
-
-    def getPicklePath(self):
-        return os.path.sep + \
-               os.path.join('tmp', 'TestExecute.TestParameterSweep1.testExecute2')
+            ['"echoed %s : 1"' % self.__class__.__name__,
+             '"echoed %s : 2"' % self.__class__.__name__])
+        return
 
 
     # END class TestParameterSweep1
@@ -480,10 +577,6 @@ class TestParameterSweep2(BaseTestClass, unittest.TestCase):
     INPUT_FILES = ['text1', 'text2']
     OUTPUT_FILES = ['count1', 'count2']
     
-    def getPicklePath(self):
-        return os.path.sep + \
-               os.path.join('tmp', 'TestExecute.TestParameterSweep2.testExecute2')
-
     def removeFile(self, file):
         try:
             os.remove(file)
@@ -573,23 +666,16 @@ class TestParameterSweep2(BaseTestClass, unittest.TestCase):
 
         return compositeDefinition
 
-        
-    def createTask(self, definition):
-
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        compositeTask.setParameterBinding(
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding(
             'input file',
             self.inputFiles
         )
-        compositeTask.setParameterBinding(
+        task.setParameterBinding(
             'output file',
             self.outputFiles
         )
-        
-        return compositeTask
+        return
 
         
     def assertPreExecute(self):
@@ -705,23 +791,16 @@ class TestParameterSweep3(BaseTestClass, unittest.TestCase):
 
         return compositeDefinition
 
-
-    def createTask(self, definition):
-
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        compositeTask.setParameterBinding(
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding(
             'input files',
             self.inputFiles
         )
-        compositeTask.setParameterBinding(
+        task.setParameterBinding(
             'output file',
             self.outputFiles
         )
-        return compositeTask
-        
+        return
 
     def assertPreExecute(self):
 
@@ -749,10 +828,6 @@ class TestParameterSweep3(BaseTestClass, unittest.TestCase):
         
         return 
 
-    def getPicklePath(self):
-        return os.path.sep + \
-               os.path.join('tmp', 'TestExecute.TestParameterSweep3.testExecute2')
-
     # END class TestParameterSweep3
     pass
 
@@ -878,26 +953,20 @@ class TestParameterSweep4(BaseTestClass, unittest.TestCase):
         return compositeDefinition
 
 
-    def createTask(self, definition):
-
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        compositeTask.setParameterBinding(
+    def bindTaskParameterValues(self, task):
+        task.setParameterBinding(
             'input file',
             self.inputFiles
         )
-        compositeTask.setParameterBinding(
+        task.setParameterBinding(
             'output file',
             self.outputFiles
         )
-        compositeTask.setParameterBinding(
+        task.setParameterBinding(
             'intermediate file',
             self.intermediateFiles
         )
-        return compositeTask
-
+        return
 
     def assertPostExecute(self):
         BaseTestClass.assertPostExecute(self)
@@ -909,14 +978,285 @@ class TestParameterSweep4(BaseTestClass, unittest.TestCase):
         
         return
         
-    def getPicklePath(self):
-        return os.path.sep + \
-               os.path.join('tmp', 'TestExecute.TestParameterSweep4.testExecute2')
-
     # END class TestParameterSweep4
     pass
 
 
+class BaseNestTestClass(object):
+
+    ATOMIC_DEFINITION = DEFINITION_ECHO
+
+    def createDefinitionWithEmptyNest(self):
+
+        nestContext = self.builder.createNewNestPomset('nest')
+        nestDefinition = nestContext.pomset()
+
+        parentContext = self.builder.createNewNestPomset('parent')
+        parentDefinition = parentContext.pomset()
+
+        atomicNode1 = self.builder.createNewNode(
+            parentDefinition,
+            name='atomic node 1',
+            definitionToReference=BaseNestTestClass.ATOMIC_DEFINITION)
+        atomicNode2 = self.builder.createNewNode(
+            parentDefinition,
+            name='atomic node 2',
+            definitionToReference=BaseNestTestClass.ATOMIC_DEFINITION)
+        nestNode = self.builder.createNewNode(
+            parentDefinition,
+            name='nest node',
+            definitionToReference=nestDefinition)
+
+        self.builder.bindParameterValue(atomicNode1, 'item to echo', ['foo 1'])
+        self.builder.bindParameterValue(atomicNode2, 'item to echo', ['foo 2'])
+
+        return parentDefinition
+
+    
+    def createDefinitionWithNonEmptyNest(self):
+        parentDefinition = self.createDefinitionWithEmptyNest()
+
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+        nestDefinition = nestNode.definitionToReference()
+
+        atomicNode3 = self.builder.createNewNode(
+            nestDefinition,
+            name='atomic node 3',
+            definitionToReference=BaseNestTestClass.ATOMIC_DEFINITION)
+
+        self.builder.bindParameterValue(atomicNode3, 'item to echo', ['foo 3'])
+
+        return parentDefinition
+
+    # END BaseNestTestClass
+    pass
+
+
+class TestNest1(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output', 
+            nestNode, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            nestNode, 'temporal output',
+            atomicNode2, 'temporal input')
+
+        return parentDefinition
+
+
+    # END class TestNest1
+    pass
+
+
+class TestNest2(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithNonEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output', 
+            nestNode, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            nestNode, 'temporal output',
+            atomicNode2, 'temporal input')
+
+        return parentDefinition
+
+    # END class TestNest2
+    pass
+
+
+class TestNest3(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithNonEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output', 
+            atomicNode2, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            nestNode, 'temporal output',
+            atomicNode2, 'temporal input')
+
+        return parentDefinition
+
+    # END class TestNest3
+    pass
+
+
+class TestNest4(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithNonEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output', 
+            nestNode, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output',
+            atomicNode2, 'temporal input')
+
+        return parentDefinition
+
+    # END class TestNest4
+    pass
+
+
+class TestNest5(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithNonEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output', 
+            nestNode, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output',
+            atomicNode2, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            nestNode, 'temporal output',
+            atomicNode2, 'temporal input')
+
+        return parentDefinition
+
+    # END class TestNest5
+    pass
+
+class TestNest6(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithNonEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output', 
+            nestNode, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output',
+            atomicNode2, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            atomicNode2, 'temporal output',
+            nestNode, 'temporal input')
+
+        return parentDefinition
+
+    # END class TestNest6
+    pass
+
+class TestNest7(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithNonEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            atomicNode1, 'temporal output', 
+            nestNode, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            atomicNode2, 'temporal output',
+            nestNode, 'temporal input')
+
+        return parentDefinition
+
+    # END class TestNest7
+    pass
+
+
+class TestNest8(BaseTestClass, BaseNestTestClass, unittest.TestCase):
+
+    def createDefinition(self):
+        parentDefinition = BaseNestTestClass.createDefinitionWithNonEmptyNest(self)
+        
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 1']
+        atomicNode1 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'atomic node 2']
+        atomicNode2 = nodes[0]
+        nodes = [x for x in parentDefinition.nodes() if x.name() == 'nest node']
+        nestNode = nodes[0]
+
+        self.builder.connect(
+            parentDefinition,
+            nestNode, 'temporal output', 
+            atomicNode1, 'temporal input')
+        self.builder.connect(
+            parentDefinition,
+            nestNode, 'temporal output',
+            atomicNode2, 'temporal input')
+
+        return parentDefinition
+
+    # END class TestNest8
+    pass
+
+
+
 class TestLoop1(BaseTestClass, unittest.TestCase):
     
     BASE_DIR = os.path.join(os.getcwd(), 'resources', 'testdata', 'TestExecute')
@@ -993,19 +1333,8 @@ class TestLoop1(BaseTestClass, unittest.TestCase):
         )
         
         return definition
-    
-    def createTask(self, definition):
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        return compositeTask
 
     
-    def getPicklePath(self):
-        return os.path.sep + os.path.join('tmp', 'TestExecute.TestLoop1.testExecute2')
-    
-
     def assertPostExecute(self):
         BaseTestClass.assertPostExecute(self)
         
@@ -1105,20 +1434,8 @@ class TestBranch1(BaseTestClass, unittest.TestCase):
         
         return definition
 
-    
-    def createTask(self, definition):
-        compositeTask = TaskModule.CompositeTask()
-        compositeTask.definition(definition)
-        taskGenerator = TaskModule.NestTaskGenerator()
-        compositeTask.taskGenerator(taskGenerator)
-        return compositeTask
 
     
-    def getPicklePath(self):
-        return os.path.sep + \
-               os.path.join('tmp', 'TestExecute.TestBranch1.testExecute2')
-
-
     def assertPostExecute(self):
         BaseTestClass.assertPostExecute(self)
         
@@ -1130,73 +1447,6 @@ class TestBranch1(BaseTestClass, unittest.TestCase):
     pass
 
 
-class TestCase11(TestCase1):
-    """
-    execute of atomic function
-    """
-
-    def getNumWorkersToInstantiate(self):
-        return 0
-
-    
-    def executeTask(self, task, 
-                    executeEnvironmentMap=None):
-
-        automaton = self.automaton
-        successCallback = automaton.getPostExecuteCallbackFor(task)
-        errorCallback = automaton.getErrorCallbackFor(task)
-        executeTaskFunction = automaton.getExecuteTaskFunction(task)
-        
-        requestContext = self.getRequestContext(
-            task=task, executeEnvironmentMap=executeEnvironmentMap
-        )
-        request = threadpool.WorkRequest(
-            executeTaskFunction,
-            args = [],
-            kwds = requestContext,
-            callback = successCallback,
-            exc_callback = errorCallback
-        )
-
-        try:
-            automaton.enqueueRequest(request)
-            assert False
-        except ErrorModule.ExecutionError, e:
-            self.assertEquals('need to start thread before execution',
-                              str(e))
-
-        return request
-
-
-
-    # END TestCase11
-    pass
-
-
-
-def main():
-    
-    util.configLogging()
-
-    suite = unittest.TestSuite()
-
-    suite.addTest(unittest.makeSuite(TestCase1, 'test'))
-    suite.addTest(unittest.makeSuite(TestCase2, 'test'))
-    suite.addTest(unittest.makeSuite(TestCase4, 'test'))
-    suite.addTest(unittest.makeSuite(TestCase8, 'test'))
-    suite.addTest(unittest.makeSuite(TestCase9, 'test'))
-    suite.addTest(unittest.makeSuite(TestCase10, 'test'))
-    suite.addTest(unittest.makeSuite(TestParameterSweep1, 'test'))
-    suite.addTest(unittest.makeSuite(TestParameterSweep2, 'test'))
-    suite.addTest(unittest.makeSuite(TestParameterSweep3, 'test'))
-    suite.addTest(unittest.makeSuite(TestParameterSweep4, 'test'))
-    suite.addTest(unittest.makeSuite(TestLoop1, 'test'))
-    suite.addTest(unittest.makeSuite(TestBranch1, 'test'))
-    
-    runner = unittest.TextTestRunner()
-    runner.run(suite)
-    return
-
 if __name__=="__main__":
     main()
 
